# PKPD example - PK parameters passed as regressors
#
# Consideration of NONMEM only

library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_neutropenia.R")

# Structural model
# PK/PD model
model <- IQRmodel("model_neutropenia.txt")

# Data
# Individual PK parameters defined in dataset
data <- data_IQRest(
  datafile = "dataNLME.csv",
  covNames = c("WT", "HT"),
  # Define regressors (PK) parameters in the same order
  # In the dataset and in the model
  regressorNames  = c("Vp","Vc","CL","Q")
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type = "BOLUS")
)

# Model specification - without covariates
modelSpec <- modelSpec_IQRest(

  # Typical subject parameters
  POPvalues0      = c(CIRC0 = 7.21, MTT = 124,  SLOPU = 28.9,  GAMMA = 0.239),
  POPestimate     = c(CIRC0 = 1   , MTT = 1 ,   SLOPU =  1,    GAMMA =  1),
  
  # Between subject variability
  IIVdistribution = c(CIRC0 ="L" ,  MTT ="L" ,  SLOPU ="N" ,   GAMMA ="L"),
  IIVvalues0      = c(CIRC0 = 0.5,  MTT = 0.5,  SLOPU = 10,    GAMMA = 0.1),
  IIVestimate     = c(CIRC0 = 1  ,  MTT = 1  ,  SLOPU = 1  ,   GAMMA = 2  ),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="abs", abs0 = 0.1))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec)

# Generate NONMEM model
proj    <- IQRnlmeProject(
  est,
  comment = "Neutropenia model - no covariates",
  projectPath = "MODEL_01",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model without covariates
run_IQRnlmeProject(proj,ncores=12)


