# Generation of VPCs and pcVPCs
rm(list=ls())
library(IQRtools)
library(ggplot2)
IQRinitCompliance("example_vpc_1.R")

# Define model to generate the VPC for
NLMEMODEL <- "MODEL_01_MONOLIX"

# -------------------------------------------------------------------------#
# Simple VPC ----
# -------------------------------------------------------------------------#

# Generate the VPC information
# Dataset is used that was used for modeling
vpc <- vpc_IQRnlmeProject(
  project = NLMEMODEL,         # Point to NLME Model (IQRnlmeProject)
  Ntrials = 200,               # Nunber of trials to simulate
  FLAGpreparePC = TRUE,        # If TRUE then information for a pcVPC will be generated in addition
  ncores = 10                  # Parallelization on 10 cores
)

# Plot the VPC
plotVPC_IQRdataVPC(vpc)

# Plot the pcVPC on logY axis
plotVPC_IQRdataVPC(vpc,FLAGpc = TRUE,FLAGlogY = TRUE)

# Modify output as desired
out <- plotVPC_IQRdataVPC(vpc,FLAGpc = TRUE,FLAGlogY = TRUE)
out$OUTPUT1$content[[1]] + 
  coord_cartesian(ylim=c(0.8,12)) + 
  ggtitle("Annotated pcVPC") 

# -------------------------------------------------------------------------#
# Dose-normalized VPC ----
# -------------------------------------------------------------------------#

# Get dataset used for modeling
data <-getData_IQRnlmeProject(NLMEMODEL)

# Normalize doses and observations
data$DV <- data$DV/data$DOSE
data$AMT <- data$AMT/data$DOSE
data$UNIT <- paste0(data$UNIT,"/mg")
data$NAME[data$EVID==0] <- "Dose-normalized Concentration"

# Generate the VPC for changed dataset
vpc <- vpc_IQRnlmeProject(
  project = NLMEMODEL,         # Point to NLME Model (IQRnlmeProject)
  dataVPC = data,              # Provide modified data
  Ntrials = 200,               # Nunber of trials to simulate
  ncores = 10,                 # Parallelization on 10 cores
  FLAGaddResidualNoise = FALSE # Switch of residual error ... 
                               # try with set to TRUE ... 
                               # not a good idea here ... pcVPC better ...
                               # or normalize to a higher dose than 1 mg!
)

# Plot the VPC
plotVPC_IQRdataVPC(vpc,FLAGlogY = TRUE)
