# Generation of VPCs and pcVPCs
rm(list=ls())
library(IQRtools)
library(ggplot2)
IQRinitCompliance("example_vpc_2.R")

# Define model to generate the VPC for
NLMEMODEL <- "MODEL_02_NONMEM"

# -------------------------------------------------------------------------#
# Simple VPC ----
# -------------------------------------------------------------------------#

# Determine regimen column for stratification
data <- getData_IQRnlmeProject(NLMEMODEL)
data$REGIMEN <- ifelse(grepl("single",data$TRTNAME),"Single Dose","Multiple Dose")
data$TRTNAME <- gsub(":::"," ",data$TRTNAME)

# Generate the VPC information
# Dataset is used that was used for modeling
vpc <- vpc_IQRnlmeProject(
  project = NLMEMODEL,         # Point to NLME Model (IQRnlmeProject)
  dataVPC = data,              # Use modified data
  Ntrials = 200,               # Nunber of trials to simulate
  ncores = 10,                 # Parallelization on 10 cores
  FLAGpreparePC = TRUE
)

# Plot the VPC
plotVPC_IQRdataVPC(vpc)

# -------------------------------------------------------------------------#
# Stratify by TRTNAME ----
# -------------------------------------------------------------------------#

# Plot the VPC
plotVPC_IQRdataVPC(vpc,stratifyBy = "TRTNAME",FLAGlogY = TRUE)

# Plot and export to PDF
plotVPC_IQRdataVPC(vpc,stratifyBy = "TRTNAME",FLAGlogY = TRUE,filename = "VPC_TRTNAME.pdf")


# -------------------------------------------------------------------------#
# Stratify by Regimen ----
# -------------------------------------------------------------------------#

# Plot the VPC
plotVPC_IQRdataVPC(vpc,stratifyBy = "REGIMEN",FLAGlogY = TRUE)

# Plot the pcVPC
plotVPC_IQRdataVPC(vpc,stratifyBy = "REGIMEN",FLAGpc = TRUE,FLAGlogY = TRUE)
