# 2 compartmental distribution model with first order absorption
# Covariates
#
# Consideration of NONMEM only

library(IQRtools)
rm(list = ls())
IQRinitCompliance("example_covariates.R")

# Structural model
model <- IQRmodel("ModelLibraryPK/model_2cpt_linear_abs1.txt")

# Data
data <- data_IQRest(
  datafile = "Data/data.csv",
  covNames = c("HT0", "WT0", "AGE"),
  catNames  = c("SEX")
)

# Define dosing
dosing <- dosing_IQRest(
  INPUT1 = c(type = "BOLUS")
)

# -------------------------------------------------------------------------#
# Model without covariates ----
# -------------------------------------------------------------------------#

# Model specification - without covariates
modelSpec1 <- modelSpec_IQRest(
  
  # Typical subject parameters
  POPvalues0  = c(kabs = 0.25, CL = 30, Vc = 30, Q1 = 25, Vp1 = 2300),
  POPestimate = c(kabs = 1   , CL = 1 , Vc =  1, Q1 =  1, Vp1 =    1),
  
  # Between subject variability
  IIVdistribution = c(kabs ="L" , CL ="L" , Vc ="L" , Q1 ="L" , Vp1 ="L" ),
  IIVvalues0      = c(kabs = 0.5, CL = 0.5, Vc = 0.5, Q1 = 0.5, Vp1 = 0.5),
  IIVestimate     = c(kabs = 1  , CL = 1  , Vc = 1  , Q1 = 1  , Vp1 = 1  ),
  
  # Error model
  errorModel = list(OUTPUT1 = c(type="rel", rel0 = 0.2))
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "No covariates",
  projectPath = "Models/MODEL_01_nocov",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model without covariates
run_IQRnlmeProject(proj,ncores=12)


# -------------------------------------------------------------------------#
# Model with covariates ----
# -------------------------------------------------------------------------#

# Define covariates on parameters
modelSpec1$covariateModel  = list(
  kabs = c("AGE","SEX"),
  CL   = c("SEX","WT0"),
  Vc   = c("SEX")
)

# Estimation object
est <- IQRnlmeEst(model=model, dosing = dosing, data = data, modelSpec = modelSpec1)

proj    <- IQRnlmeProject(
  est,
  comment = "SEX on CL/Vc/kabs, WT0 on CL, AGE on kabs",
  projectPath = "Models/MODEL_02_cov",
  tool = "NONMEM",
  algOpt.NONMEM.METHOD = "SAEM",
  algOpt.NONMEM.ITS = FALSE,
  algOpt.K1 = 200,
  algOpt.K2 = 50
)

# Run the model without covariates
run_IQRnlmeProject(proj,ncores=12)


